==> haskell-pango-0.13.11.0-108.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   pango
version:                0.13.11.0
visibility:             public
id:                     pango-0.13.11.0-CJe3nD1y4grDoPVCWTnk4C
key:                    pango-0.13.11.0-CJe3nD1y4grDoPVCWTnk4C
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.

category:               Graphics
abi:                    1e6e478c2c3294f9e03beefa29b59775
exposed:                True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types

hidden-modules:
    Graphics.Rendering.Pango.GlyphStorage
    Graphics.Rendering.Pango.Description

import-dirs:            /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-pango
hs-libraries:           HSpango-0.13.11.0-CJe3nD1y4grDoPVCWTnk4C
extra-libraries:
    pangocairo-1.0 pango-1.0 harfbuzz gobject-2.0 glib-2.0 cairo

extra-libraries-static:
    pangocairo-1.0 m pangoft2-1.0 m harfbuzz-gobject pango-1.0 m
    harfbuzz m graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 m
    pcre2-8 pthread mount blkid fribidi thai datrie Xft cairo m dl
    fontconfig m expat m freetype dl bz2 png16 m m z brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m sysprof-capture-4

include-dirs:
    /usr/include/pango-1.0 /usr/include/harfbuzz /usr/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/fribidi
    /usr/include/cairo /usr/include/freetype2 /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/sysprof-6

includes:               hspango.h
depends:
    array-0.5.6.0 base-4.18.2.1 cairo-0.13.12.0-BiwVnSgGXm15PnXZRv298w
    containers-0.6.7 directory-1.3.8.5
    glib-0.13.12.0-HTF9u3giCcNJUcsSvVCBJJ mtl-2.3.1 pretty-1.1.3.6
    process-1.6.19.0 text-2.0.2

haddock-interfaces:     /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html:           /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.11.0-109-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   pango
version:                0.13.11.0
visibility:             public
id:                     pango-0.13.11.0-I7WesFpcii34WA2D3U0oBU
key:                    pango-0.13.11.0-I7WesFpcii34WA2D3U0oBU
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.

category:               Graphics
abi:                    b70f0a0af01716d3ad121c0117acfa44
exposed:                True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types

hidden-modules:
    Graphics.Rendering.Pango.GlyphStorage
    Graphics.Rendering.Pango.Description

import-dirs:            /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/pango-0.13.11.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-pango
hs-libraries:           HSpango-0.13.11.0-I7WesFpcii34WA2D3U0oBU
extra-libraries:
    pangocairo-1.0 pango-1.0 harfbuzz gobject-2.0 glib-2.0 cairo

extra-libraries-static:
    pangocairo-1.0 m pangoft2-1.0 m harfbuzz-gobject pango-1.0 m
    harfbuzz m graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread mount blkid fribidi thai datrie Xft cairo
    m dl fontconfig m expat m freetype dl bz2 png16 m m z brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m sysprof-capture-4

include-dirs:
    /usr/include/pango-1.0 /usr/include/harfbuzz /usr/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/fribidi
    /usr/include/cairo /usr/include/freetype2 /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/sysprof-6

includes:               hspango.h
depends:
    array-0.5.6.0 base-4.18.2.1 cairo-0.13.12.0-3aBf3J5x54XF9reOVk3EKF
    containers-0.6.7 directory-1.3.8.5
    glib-0.13.12.0-8CzwgWPylls3gjbTcFMC2x mtl-2.3.1 pretty-1.1.3.6
    process-1.6.19.0 text-2.0.2

haddock-interfaces:     /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html:           /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
